==> qtjambi-location-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiLocation/QPlaceDetailsReply_shell.h <==
#ifndef QPLACEDETAILSREPLY_SHELL_H
#define QPLACEDETAILSREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtLocation/qplacedetailsreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtLocation/qplace.h>
#include <QtLocation/qplacereply.h>
#include <QtJambi/RegistryAPI>


class QPlaceDetailsReply_shell : public QPlaceDetailsReply, public QtJambiShellInterface
{
public:
    QPlaceDetailsReply_shell(QObject* parent0 = nullptr);
    ~QPlaceDetailsReply_shell() override;

    void abort() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QPlaceReply::Type type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceDetailsReply_access : public QPlaceDetailsReply
{
    void __qt_setPlace_cref_QPlace(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID place0);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPLACEDETAILSREPLY_SHELL_H

==> qtjambi-location-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiLocation/QPlaceDetailsReply_shell.h <==
#ifndef QPLACEDETAILSREPLY_SHELL_H
#define QPLACEDETAILSREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtLocation/qplacedetailsreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtLocation/qplace.h>
#include <QtLocation/qplacereply.h>
#include <QtJambi/RegistryAPI>


class QPlaceDetailsReply_shell : public QPlaceDetailsReply, public QtJambiShellInterface
{
public:
    QPlaceDetailsReply_shell(QObject* parent0 = nullptr);
    ~QPlaceDetailsReply_shell() override;

    void abort() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QPlaceReply::Type type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceDetailsReply_access : public QPlaceDetailsReply
{
    void __qt_setPlace_cref_QPlace(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID place0);
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPLACEDETAILSREPLY_SHELL_H
